#ifndef TEXTFIELD_H
#define TEXTFIELD_H

#include <QTextEdit>
#include <QWidget>

class TextField : public QTextEdit
{
    Q_OBJECT
public:
    explicit TextField(QWidget *parent = 0);
    //void setReadOnly(bool ro);
    //void setEnabled(bool);

signals:

public slots:

protected:
    //void mouseReleaseEvent(QMouseEvent *e);
    bool eventFilter(QObject *, QEvent *);

};

#endif // TEXTFIELD_H
